@@ -15,27 +15,27 @@ class GeneralTaskModule(LightningModule):
         # 存放训练、验证、测试过程中的各种消息数据
         self.messages = dict()
 
-    def forward(self, batch_data):                          # 前向计算
-        return self.model(batch_data)
+    def forward(self, *batch_data):                         # 前向计算
+        return self.model(*batch_data)
 
     def training_step(self, batch, batch_nb):               # 训练步
         loss, preds, targets = self.do_forward(batch)
-        self.log('train_loss', loss, on_step=self.on_step, on_epoch=self.on_epoch)
-        self.do_metric(preds, targets, self.log)
+        self.log('train_loss', loss.detach(), on_step=self.on_step, on_epoch=self.on_epoch)
+        self.do_metric(preds, targets, 'train', self.log)
         self.messages['train_batch'] = (batch_nb, preds, targets) # (batch_idx, preds, tagets)
         return loss
 
     def validation_step(self, batch, batch_nb):             # 验证步
         loss, preds, targets = self.do_forward(batch)
-        self.log('val_loss', loss, prog_bar=True, on_step=self.on_step, on_epoch=self.on_epoch)
-        self.do_metric(preds, targets, self.log)
+        self.log('val_loss', loss.detach(), prog_bar=True, on_step=self.on_step, on_epoch=self.on_epoch)
+        self.do_metric(preds, targets, 'val', self.log)
         self.messages['val_batch'] = (batch_nb, preds, targets) # (batch_idx, preds, tagets)
         return {'val_loss': loss}
 
     def test_step(self, batch, batch_nb):                   # 测试步
         loss, preds, targets = self.do_forward(batch)
-        self.log('test_loss', loss, prog_bar=True)
-        self.do_metric(preds, targets, self.log)
+        self.log('test_loss', loss.detach(), prog_bar=True)
+        self.do_metric(preds, targets, 'test', self.log)
         self.messages['test_batch'] = (batch_nb, preds, targets) # (batch_idx, preds, tagets)
         return {'test_loss': loss}
 
@@ -48,7 +48,7 @@ class GeneralTaskModule(LightningModule):
         loss = self.loss_fn(preds, targets)
         return loss, preds, targets
 
-    def do_metric(self, preds, targets, log):               # 指标计算
+    def do_metric(self, preds, targets, state, log):               # 指标计算
         for metric in self.metrics:
             result = metric(preds, targets)
             if isinstance(metric, MetricBase):
@@ -58,4 +58,4 @@ class GeneralTaskModule(LightningModule):
             else:
                 name = metric.__name__
                 on_step, on_epoch = True, True
-            log(name, result, prog_bar=True, on_step=on_step, on_epoch=on_epoch)
+            log(f"{state}_{name}", result.detach(), prog_bar=True, on_step=on_step, on_epoch=on_epoch)
